==> haskell-tagsoup-0.14.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagsoup
version: 0.14.1
id: tagsoup-0.14.1-A8v7iyBjfz82GOKyhT5ypk
key: tagsoup-0.14.1-A8v7iyBjfz82GOKyhT5ypk
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/tagsoup#readme
synopsis: Parsing and extracting information from (possibly malformed) HTML/XML documents
description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.
    .
    Users should start from the "Text.HTML.TagSoup" module.
category: XML
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike
hidden-modules: Text.HTML.TagSoup.Generated
                Text.HTML.TagSoup.Implementation Text.HTML.TagSoup.Manual
                Text.HTML.TagSoup.Options Text.HTML.TagSoup.Parser
                Text.HTML.TagSoup.Render Text.HTML.TagSoup.Specification
                Text.HTML.TagSoup.Type
abi: 47ff4da4110d9da21339ced945c75cb5
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/tagsoup-0.14.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/tagsoup-0.14.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/tagsoup-0.14.1
hs-libraries: HStagsoup-0.14.1-A8v7iyBjfz82GOKyhT5ypk
depends:
    base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html: /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagsoup-0.14.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagsoup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagsoup
version: 0.14.1
id: tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
key: tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/tagsoup#readme
synopsis: Parsing and extracting information from (possibly malformed) HTML/XML documents
description:
    TagSoup is a library for parsing HTML/XML. It supports the HTML 5 specification,
    and can be used to parse either well-formed XML, or unstructured and malformed HTML
    from the web. The library also provides useful functions to extract information
    from an HTML document, making it ideal for screen-scraping.
    .
    Users should start from the "Text.HTML.TagSoup" module.
category: XML
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.HTML.TagSoup Text.HTML.TagSoup.Entity Text.HTML.TagSoup.Match
    Text.HTML.TagSoup.Tree Text.StringLike
hidden-modules: Text.HTML.TagSoup.Generated
                Text.HTML.TagSoup.Implementation Text.HTML.TagSoup.Manual
                Text.HTML.TagSoup.Options Text.HTML.TagSoup.Parser
                Text.HTML.TagSoup.Render Text.HTML.TagSoup.Specification
                Text.HTML.TagSoup.Type
abi: 3fbcc782bd8302af2fafeef32df01fde
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tagsoup-0.14.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tagsoup-0.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tagsoup-0.14.1
hs-libraries: HStagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
depends:
    base-4.10.0.0 containers-0.5.10.2 bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
haddock-interfaces: /usr/share/doc/haskell-tagsoup/html/tagsoup.haddock
haddock-html: /usr/share/doc/haskell-tagsoup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
